@@ -103,7 +103,7 @@ drdid_imp_rc <- function(y, post, D, covariates, i.weights = NULL, boot = FALSE,
   #Compute the Pscore using the pscore.cal
   pscore.ipt <- pscore.cal(D, int.cov, i.weights = i.weights, n = n)
   ps.fit <- as.vector(pscore.ipt$pscore)
-  ps.fit <- pmin(ps.fit, 1 - 1e-16)
+  ps.fit <- pmin(ps.fit, 1 - 1e-6)
   #Compute the Outcome regression for the control group
   out.y.cont.pre <- wols_rc(y, post, D, int.cov, ps.fit, i.weights, pre = TRUE, treat = FALSE)
   out.y.cont.pre <-  as.vector(out.y.cont.pre$out.reg)
@@ -113,14 +113,28 @@ drdid_imp_rc <- function(y, post, D, covariates, i.weights = NULL, boot = FALSE,
   out.y.cont <- post * out.y.cont.post + (1 - post) * out.y.cont.pre
   #-----------------------------------------------------------------------------
   #Compute the Outcome regression for the treated group at the pre-treatment period, using ols.
-  reg.treat.coeff.pre <- stats::coef(stats::lm(y ~ -1 + int.cov,
-                                               subset = ((D==1) & (post==0)),
-                                               weights = i.weights))
+  # reg.treat.coeff.pre <- stats::coef(stats::lm(y ~ -1 + int.cov,
+  #                                              subset = ((D==1) & (post==0)),
+  #                                              weights = i.weights))
+  treat_pre_filter <- (D == 1) & (post == 0)
+  reg.treat.coeff.pre <- stats::coef(fastglm::fastglm(
+                                      x = int.cov[treat_pre_filter, , drop = FALSE],
+                                      y = y[treat_pre_filter],
+                                      weights = i.weights[treat_pre_filter],
+                                      family = gaussian(link = "identity")
+  ))
   out.y.treat.pre <-   as.vector(tcrossprod(reg.treat.coeff.pre, int.cov))
   #Compute the Outcome regression for the treated group at the post-treatment period, using ols.
-  reg.treat.coeff.post <- stats::coef(stats::lm(y ~ -1 + int.cov,
-                                                subset = ((D==1) & (post==1)),
-                                                weights = i.weights))
+  # reg.treat.coeff.post <- stats::coef(stats::lm(y ~ -1 + int.cov,
+  #                                               subset = ((D==1) & (post==1)),
+  #                                               weights = i.weights))
+  treat_post_filter <- (D == 1) & (post == 1)
+  reg.treat.coeff.post <- stats::coef(fastglm::fastglm(
+                                      x = int.cov[treat_post_filter, , drop = FALSE],
+                                      y = y[treat_post_filter],
+                                      weights = i.weights[treat_post_filter],
+                                      family = gaussian(link = "identity")
+  ))
   out.y.treat.post <-   as.vector(tcrossprod(reg.treat.coeff.post, int.cov))
   #-----------------------------------------------------------------------------
   # First, the weights
